"""
    A Report plugin to save a report to a local file.
    Copyright (C) 2009 Red Hat, Inc

    Author: Gavin Romig-Koch <gavin@redhat.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License along
    with this program; if not, write to the Free Software Foundation, Inc.,
    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
"""

import os
import stat
import shutil

from report import io as iomodule

import gettext
_ = lambda x: gettext.ldgettext("report", x)


label = "local"
description = "save the file locally"

def report(signature, io):
    fileName = None

    if signature.has_key("pythonUnhandledException"):
        fileName = signature["pythonUnhandledException"].asFileName()

    elif signature.has_key("description"):
        fileName = signature["description"].asFileName()

    elif signature.has_key("signature"):
        fileName = signature["signature"].asFileName()
    else:
        raise ValueError("signature contains neither a 'signature', 'description', nor a 'pythonUnhandledException'")

    return copyFile(fileName, io)

def copyFile(fileName, io):

    dirpath = io.queryField("directory to store report in")
    if not dirpath or dirpath.strip() == "":
        return False

    if os.path.exists(dirpath):
        mode = os.stat(dirpath)[stat.ST_MODE]
        if not stat.S_ISDIR(mode):
            io.failMessage(_("local save Failed"),
                           _("'%s' already exists, but is not a directory") % dirpath)
            return False
    else:
        createp = io.queryChoice(_("'%s' does not exist, create it?") % dirpath,
                                 [ iomodule.ChoiceValue("OK",
                                                        "Create the directory",
                                                        True),
                                   iomodule.ChoiceValue("Cancel",
                                                        "Cancel the local save",
                                                        False) ])
        if not createp:
            return False
        
        try:
            os.makedirs(dirpath)

        except EnvironmentError, e:
            io.failMessage(_("local save Failed"),
                           _("could not create '%s': %s") % (dirpath,str(e)))
            return False
            
    target = "%s/%s" % (dirpath, os.path.basename(fileName))
    try:
        shutil.copyfile(fileName, target)

    except EnvironmentError, e:
        io.failMessage(_("local save Failed"),
                       _("could not save report to '%s': %s") % (target,str(e)))
        return False

    io.successMessage(_("local save Successful"),
                      _("The signature was successfully copied to:"),
                      None, target)
    return True
